/**
 * A collection of movement flags.
 *
 * @group Managers
 */
export declare class MovementState {
    /**
     * Movement to the left.
     */
    left: boolean;
    /**
     * Movement to the right.
     */
    right: boolean;
    /**
     * Forward motion.
     */
    forward: boolean;
    /**
     * Backward motion.
     */
    backward: boolean;
    /**
     * Ascension.
     */
    up: boolean;
    /**
     * Descent.
     */
    down: boolean;
    /**
     * Controls whether backward movement currently has priority.
     */
    backwardBeforeForward: boolean;
    /**
     * Controls whether right movement currently has priority.
     */
    rightBeforeLeft: boolean;
    /**
     * Controls whether up movement currently has priority.
     */
    upBeforeDown: boolean;
    /**
     * Whether the boost multiplier should be used.
     */
    boost: boolean;
    /**
     * Constructs a new movement state.
     */
    constructor();
    /**
     * Indicates whether any flag is currently active.
     */
    get active(): boolean;
    /**
     * Resets this state.
     *
     * @return This state.
     */
    reset(): this;
}
